@@ -34,53 +34,103 @@
 #include "yder.h"
 
 /**
- * Private functions declarations
+ * Write log message to console output (stdout or stderr)
  */
-int   y_write_log(const char * app_name, const unsigned long init_mode, const unsigned long init_level, const char * init_log_file, const unsigned long level, const char * message);
-void  y_write_log_console(const char * app_name, const time_t date, const unsigned long level, const char * message);
-void  y_write_log_syslog(const char * app_name, const unsigned long level, const char * message);
-void  y_write_log_file(const char * app_name, const time_t date, FILE * log_file, const unsigned long level, const char * message);
-
-/**
- * Initialize logs
- */
-int y_init_logs(const char * app, const unsigned long init_mode, const unsigned long init_level, const char * init_log_file, const char * message) {
-  return y_write_log(app, init_mode, init_level, init_log_file, Y_LOG_LEVEL_INFO, message);
+static void y_write_log_console(const char * app_name, const time_t date, const unsigned long level, const char * message) {
+  char * level_name = NULL, date_stamp[20];
+  FILE * output = NULL;
+  struct tm * tm_stamp;
+  
+  tm_stamp = localtime (&date);
+  
+  strftime (date_stamp, sizeof(date_stamp), "%FT%TZ", tm_stamp);
+  switch (level) {
+    case Y_LOG_LEVEL_ERROR:
+      level_name = "ERROR";
+      break;
+    case Y_LOG_LEVEL_WARNING:
+      level_name = "WARNING";
+      break;
+    case Y_LOG_LEVEL_INFO:
+      level_name = "INFO";
+      break;
+    case Y_LOG_LEVEL_DEBUG:
+      level_name = "DEBUG";
+      break;
+    default:
+      level_name = "NONE";
+      break;
+  }
+  if (level & Y_LOG_LEVEL_WARNING || level & Y_LOG_LEVEL_ERROR) {
+    // Write to stderr
+    output = stderr;
+  } else {
+    // Write to stdout
+    output = stdout;
+  }
+  fprintf(output, "%s - %s %s: %s\n", date_stamp, app_name, level_name, message);
+  fflush(output);
 }
 
 /**
- * Close logs
+ * Write log message to syslog
  */
-int y_close_logs() {
-  return y_write_log(NULL, 0, 0, NULL, 0, NULL);
+static void y_write_log_syslog(const char * app_name, const unsigned long level, const char * message) {
+  openlog(app_name, LOG_PID|LOG_CONS, LOG_USER);
+  switch (level) {
+    case Y_LOG_LEVEL_ERROR:
+      syslog( LOG_ERR, "%s", message );
+      break;
+    case Y_LOG_LEVEL_WARNING:
+      syslog( LOG_WARNING, "%s", message );
+      break;
+    case Y_LOG_LEVEL_INFO:
+      syslog( LOG_INFO, "%s", message );
+      break;
+    case Y_LOG_LEVEL_DEBUG:
+      syslog( LOG_DEBUG, "%s", message );
+      break;
+  }
+  closelog();
 }
 
 /**
- * Write the message given in parameters to the current outputs if the current level matches
+ * Append log message to the log file
  */
-void y_log_message(const unsigned long level, const char * message, ...) {
-  va_list args, args_cpy;
-  size_t out_len = 0;
-  char * out = NULL;
-  va_start(args, message);
-  // Use va_copy to make a new args pointer to avoid problems with vsnprintf which can change args parameter on some architectures
-  va_copy(args_cpy, args);
-  out_len = vsnprintf(NULL, 0, message, args);
-  out = o_malloc((out_len + 1)*sizeof(char));
-  if (out != NULL) {
-    vsnprintf(out, (out_len + 1), message, args_cpy);
-    y_write_log(NULL, Y_LOG_MODE_CURRENT, Y_LOG_LEVEL_CURRENT, NULL, level, out);
-    o_free(out);
+static void y_write_log_file(const char * app_name, const time_t date, FILE * log_file, const unsigned long level, const char * message) {
+  char * level_name = NULL, date_stamp[20];
+  struct tm * tm_stamp;
+  
+  if (log_file != NULL) {
+    tm_stamp = localtime (&date);
+    strftime (date_stamp, sizeof(date_stamp), "%Y-%m-%d %H:%M:%S", tm_stamp);
+    switch (level) {
+      case Y_LOG_LEVEL_ERROR:
+        level_name = "ERROR";
+        break;
+      case Y_LOG_LEVEL_WARNING:
+        level_name = "WARNING";
+        break;
+      case Y_LOG_LEVEL_INFO:
+        level_name = "INFO";
+        break;
+      case Y_LOG_LEVEL_DEBUG:
+        level_name = "DEBUG";
+        break;
+      default:
+        level_name = "NONE";
+        break;
+    }
+    fprintf(log_file, "%s - %s %s: %s\n", date_stamp, app_name, level_name, message);
+    fflush(log_file);
   }
-  va_end(args);
-  va_end(args_cpy);
 }
 
 /**
  * Main function for logging messages
  * Warning ! Contains static variables used for not having to pass general configuration values every time you call log_message
  */
-int y_write_log(const char * app_name, const unsigned long init_mode, const unsigned long init_level, const char * init_log_file, const unsigned long level, const char * message) {
+static int y_write_log(const char * app_name, const unsigned long init_mode, const unsigned long init_level, const char * init_log_file, const unsigned long level, const char * message) {
   static unsigned long cur_mode = Y_LOG_MODE_NONE, cur_level = Y_LOG_LEVEL_NONE;
   FILE * cur_log_file = NULL;
   static char * cur_app_name = NULL;
@@ -155,94 +205,36 @@ int y_write_log(const char * app_name, const unsigned long init_mode, const unsi
 }
 
 /**
- * Write log message to console output (stdout or stderr)
+ * Initialize logs
  */
-void y_write_log_console(const char * app_name, const time_t date, const unsigned long level, const char * message) {
-  char * level_name = NULL, date_stamp[20];
-  FILE * output = NULL;
-  struct tm * tm_stamp;
-  
-  tm_stamp = localtime (&date);
-  
-  strftime (date_stamp, sizeof(date_stamp), "%FT%TZ", tm_stamp);
-  switch (level) {
-    case Y_LOG_LEVEL_ERROR:
-      level_name = "ERROR";
-      break;
-    case Y_LOG_LEVEL_WARNING:
-      level_name = "WARNING";
-      break;
-    case Y_LOG_LEVEL_INFO:
-      level_name = "INFO";
-      break;
-    case Y_LOG_LEVEL_DEBUG:
-      level_name = "DEBUG";
-      break;
-    default:
-      level_name = "NONE";
-      break;
-  }
-  if (level & Y_LOG_LEVEL_WARNING || level & Y_LOG_LEVEL_ERROR) {
-    // Write to stderr
-    output = stderr;
-  } else {
-    // Write to stdout
-    output = stdout;
-  }
-  fprintf(output, "%s - %s %s: %s\n", date_stamp, app_name, level_name, message);
-  fflush(output);
+int y_init_logs(const char * app, const unsigned long init_mode, const unsigned long init_level, const char * init_log_file, const char * message) {
+  return y_write_log(app, init_mode, init_level, init_log_file, Y_LOG_LEVEL_INFO, message);
 }
 
 /**
- * Write log message to syslog
+ * Close logs
  */
-void y_write_log_syslog(const char * app_name, const unsigned long level, const char * message) {
-  openlog(app_name, LOG_PID|LOG_CONS, LOG_USER);
-  switch (level) {
-    case Y_LOG_LEVEL_ERROR:
-      syslog( LOG_ERR, "%s", message );
-      break;
-    case Y_LOG_LEVEL_WARNING:
-      syslog( LOG_WARNING, "%s", message );
-      break;
-    case Y_LOG_LEVEL_INFO:
-      syslog( LOG_INFO, "%s", message );
-      break;
-    case Y_LOG_LEVEL_DEBUG:
-      syslog( LOG_DEBUG, "%s", message );
-      break;
-  }
-  closelog();
+int y_close_logs() {
+  return y_write_log(NULL, 0, 0, NULL, 0, NULL);
 }
 
 /**
- * Append log message to the log file
+ * Write the message given in parameters to the current outputs if the current level matches
  */
-void y_write_log_file(const char * app_name, const time_t date, FILE * log_file, const unsigned long level, const char * message) {
-  char * level_name = NULL, date_stamp[20];
-  struct tm * tm_stamp;
-  
-  if (log_file != NULL) {
-    tm_stamp = localtime (&date);
-    strftime (date_stamp, sizeof(date_stamp), "%Y-%m-%d %H:%M:%S", tm_stamp);
-    switch (level) {
-      case Y_LOG_LEVEL_ERROR:
-        level_name = "ERROR";
-        break;
-      case Y_LOG_LEVEL_WARNING:
-        level_name = "WARNING";
-        break;
-      case Y_LOG_LEVEL_INFO:
-        level_name = "INFO";
-        break;
-      case Y_LOG_LEVEL_DEBUG:
-        level_name = "DEBUG";
-        break;
-      default:
-        level_name = "NONE";
-        break;
-    }
-    fprintf(log_file, "%s - %s %s: %s\n", date_stamp, app_name, level_name, message);
-    fflush(log_file);
+void y_log_message(const unsigned long level, const char * message, ...) {
+  va_list args, args_cpy;
+  size_t out_len = 0;
+  char * out = NULL;
+  va_start(args, message);
+  // Use va_copy to make a new args pointer to avoid problems with vsnprintf which can change args parameter on some architectures
+  va_copy(args_cpy, args);
+  out_len = vsnprintf(NULL, 0, message, args);
+  out = o_malloc((out_len + 1)*sizeof(char));
+  if (out != NULL) {
+    vsnprintf(out, (out_len + 1), message, args_cpy);
+    y_write_log(NULL, Y_LOG_MODE_CURRENT, Y_LOG_LEVEL_CURRENT, NULL, level, out);
+    o_free(out);
   }
+  va_end(args);
+  va_end(args_cpy);
 }
